.. _source:


.. raw:: html

     <br>

.. title:: Source


**Skull, Bones and Number (OTP-CR-117/19)**

.. raw:: html

     <br>


.. autosummary::
    :toctree: 
    :template: base.rst

    sbn.brokers		list of bots
    sbn.clients         clients
    sbn.command		commands
    sbn.default         default values
    sbn.excepts		exceptions
    sbn.handler         handler
    sbn.locates         find objects
    sbn.message         event
    sbn.modules         usercode
    sbn.objects         clean namespace
    sbn.parsers         parse cli
    sbn.runtime         runtime
    sbn.storage         directory
    sbn.threads         threads


**MODULES**


.. raw:: html

     <br>


.. autosummary::
    :toctree: 
    :template: base.rst

    sbn.modules.cmd 	list of commands
    sbn.modules.dbg     raises an exception
    sbn.modules.err     show errors
    sbn.modules.fnd     locate objects
    sbn.modules.irc     internet realy chat
    sbn.modules.log     log text
    sbn.modules.mbx     mailbox
    sbn.modules.mdl     model
    sbn.modules.mod     list of modules
    sbn.modules.mre     more
    sbn.modules.pwd     sasl password
    sbn.modules.req	request
    sbn.modules.rst     rest server
    sbn.modules.rss	rich site syndicate
    sbn.modules.tdo	todo list
    sbn.modules.thr	list threads
    sbn.modules.tmr	timers
    sbn.modules.udp     udp to irc relay
    sbn.modules.wsd     bad trip
